///////////////////
//
// global variables

var map = null; // this file's map
var layerTrack = []; // array to keep layers for tracks

var dataBounds = new OpenLayers.Bounds(); // Ausdehnung der Daten

var epsg900913 = new OpenLayers.Projection("EPSG:900913");
var epsg4326 = new OpenLayers.Projection('EPSG:4326');

// Texts for service section
var serviceSectionHelpLinkText = '';
var serviceSectionDownloadLinkText = '';
var serviceSectionMapOnlyLinkText = '';

// parameters, that can be set in HTML file
var reqTrackStyle = defaultTrackStyle; // style for tracks
trackStyle['gpx'] = trackStyle[fallbackGPXtrackStyle]; // define gpx fallback colors
var reqBaseMap = defaultBaseMap; // background map
var UIlanguage = defaultUIlanguage; // language for text parts

// get filename of gps file from name of the html file
document.URL.search(/.*\/(.*?).html/);
var baseFilename = RegExp.$1;
var gpxFilename = gpxPath.concat(baseFilename,'.gpx');

/*
 * general functions
 */

// check if element exists in an array
function isElementInArray(givenElement,array) {
    for (var definedElement in array)
	if (givenElement == definedElement){
	    return true}
    return false;
}
   
// get width of map div
function getWidth() {
    if (window.innerWidth)
	return window.innerWidth;
    else if (document.documentElement && document.documentElement.clientWidth)
	return document.documentElement.clientWidth;
    else if (document.body)
	return document.body.clientWidth;
    else
	return 800}

// get height of map div
function getHeight() {
    if (window.innerHeight)
	return window.innerHeight;
    else if (document.documentElement && document.documentElement.clientHeight)
	return document.documentElement.clientHeight;
    else if (document.body)
	return document.body.clientHeight;
    else
	return 600}

// parameters given to the script are processed here
function processMapParameters(parameter){
    var keyValue = parameter.split('=',2);
    switch (keyValue[0].toLowerCase()) {
    case 'trackstyle':
	if (keyValue[1] == 'gpx'){
	    reqTrackStyle = 'gpx'}
	else {
	    if (isElementInArray(keyValue[1].toLowerCase(),trackStyle)){
		reqTrackStyle = keyValue[1].toLowerCase();
		break;}}
	break;
    case 'basemap':
	if (isElementInArray(keyValue[1],baseMap)) {
	    reqBaseMap = keyValue[1]}
	break;
    case 'alternativegpxbasemap':
	if (isElementInArray(keyValue[1],baseMap)) {
	    alternativeGpxBaseMap = keyValue[1]}
	break;
    case 'globalgpxbasemap':
	if (isElementInArray(keyValue[1],baseMap)) {
	    globalGpxBaseMap = keyValue[1]}
	break;
    case 'showdownloadlink':
	if (keyValue[1] == 'true' || keyValue[1] == '1' || keyValue[1].toLowerCase() == 'yes') {
	    showDownloadLink = true}
	else {
	    showDownloadLink = false}
	break;
    case 'showmaponlylink':
	if (keyValue[1] == 'true' || keyValue[1] == '1' || keyValue[1].toLowerCase() == 'yes') {
	    showMapOnlyLink = true}
	else {
	    showMapOnlyLink = false}
	break;
    case 'showhelppagelink':
	if (keyValue[1] == 'true' || keyValue[1] == '1' || keyValue[1].toLowerCase() == 'yes') {
	    showHelpPageLink = true}
	else {
	    showHelpPageLink = false}
	break;
    case 'showShadinglayer':
	if (keyValue[1] == 'true' || keyValue[1] == '1' || keyValue[1].toLowerCase() == 'yes') {
	    showShadingLayer = true}
	else {
	    showShadingLayer = false}
	break;
    case 'showgpxsymbols':
	if (keyValue[1] == 'true' || keyValue[1] == '1' || keyValue[1].toLowerCase() == 'yes') {
	    showGPXsymbols = true}
	else {
	    showGPXsymbols = false}
	break;
    case 'uilanguage':
	if (isElementInArray(keyValue[1],lang)) {
	    UIlanguage = keyValue[1]}
	break;
    }}



/*
 * map functions
 */

// setup service section
function setupServiceSection() {
    // initialize with help text
    var serviceSectionContent = '' + serviceSectionHelpLinkText
	// insert spacer if needed
	if (serviceSectionContent.length > 0 &&
	    serviceSectionDownloadLinkText.length > 0) {
	    serviceSectionContent += '<br />'}
    // add link to gpx file
    serviceSectionContent += serviceSectionDownloadLinkText;
    // add spacer if necessary
    if (serviceSectionContent.length > 0 &&
	serviceSectionMapOnlyLinkText.length > 0) {
	serviceSectionContent += '<br />'}
    // add link to map html page
    serviceSectionContent += serviceSectionMapOnlyLinkText;
    //put parts into service section
    document.getElementById('serviceSection').innerHTML = serviceSectionContent;
    // toggle visibility of service section
    if (serviceSectionContent.length > 0) {
	document.getElementById('serviceSection').style.display = 'block'}
    else {
	document.getElementById('serviceSection').style.display = 'none'}
}

// Tracks auf die Karte bringen
function drawTracks() {
    for (var i=0;i<layerTrack.length;i++) {
	map.addLayer(layerTrack[i]);}
}


function drawWaypoints() {
    // Waypointlayer nur einbauen, wenn vorhanden
    if (layerWaypoints.markers.length > 0) {
	map.addLayer(layerWaypoints)}}

function addMarkerWithPopup(nr,ll,symbol,text) {
    var feature = new OpenLayers.Feature(layerWaypoints, ll);
    feature.id = 'wpt' + nr;
    feature.popupClass = OpenLayers.Class(OpenLayers.Popup.FramedCloud, {
	    'maxSize': new OpenLayers.Size(500,500),
	    'minSize': new OpenLayers.Size(220,50),
	    'autoSize': true,
 	    'closeBox': false,
	    'panMapIfOutOfView': true,
	    'keepInMap': false,
	    'contentHTML': text,
	    'overflow': 'visible'});
    if (isElementInArray(symbol,waypointIcon) && showGPXsymbols == true) {
	feature.data.icon = waypointIcon[symbol].clone()}
    else {
	feature.data.icon = waypointIcon['simple'].clone();}
    // set background image
    feature.data.icon.imageDiv.style.backgroundImage =
 	'url("' + markerPath + defaultMarkerStyle + '_' + reqTrackStyle + '.png")';

    var marker = feature.createMarker();
    marker.feature = feature;
    
    // functions for popup
    function showPopup() {
	if(feature == undefined) return; 
	if (feature.popup) {
	    if (! feature.popup.visible()) {
		feature.popup.show();
		return;}}
	else {
 	    feature.popup = feature.createPopup();
	    map.addPopup(feature.popup);
	    feature.popup.show();}}
    
    function closePopup() {
	if(feature == undefined) return; 
	feature.popup.hide()}
    var markerOver = function(evt) {
	showPopup();
  	document.getElementById('map').style.cursor = "pointer"; //replacing next line:
	OpenLayers.Event.stop(feature)}
    var markerOut = function(evt) {
	closePopup();
  	document.getElementById('map').style.cursor = "auto"; //replacing next line:
	OpenLayers.Event.stop(evt)}
	
    // register the above marker events
    if (text.length > 0) {
	marker.events.register("mouseover", feature, markerOver);
	marker.events.register("mouseout", feature, markerOut)}
    layerWaypoints.addMarker(marker);
}




//////////////////////////////
//
// put GPX data into variables
function getDataFromFile (doc) {
    // get tracks from GPX-File
    var allTracks = doc.getElementsByTagName("trk");	
    for (var trackNr = 0; trackNr < allTracks.length; trackNr++) {
	layerTrack[trackNr] = new OpenLayers.Layer.Vector('');
	layerTrack[trackNr].style = trackStyle[reqTrackStyle][trackNr % 4];
	for (var trackChildNr = 0; trackChildNr < allTracks[trackNr].childNodes.length; trackChildNr++) {
	    switch (allTracks[trackNr].childNodes[trackChildNr].nodeName) {
	    case 'name': // get track name
		layerTrack[trackNr].setName
  		    (OpenLayers.Util.getXmlNodeValue(allTracks[trackNr].childNodes[trackChildNr]));
		break;
	    case 'extensions': // get extended gpx data
		if (reqTrackStyle == 'gpx') {
		    // the handling of extension data is worth of improvement
		    var allExtensions = [];
		    for (var extensionNr = 0;
			 extensionNr < allTracks[trackNr].childNodes[trackChildNr].childNodes.length;
			 extensionNr++) {
			switch(allTracks[trackNr].childNodes[trackChildNr].childNodes[extensionNr].nodeName){
			case 'gpxx:TrackExtension':
			    allExtensions.push
				(allTracks[trackNr].childNodes[trackChildNr].childNodes[extensionNr])}}
		    
		    for (var extensionNr = 0; extensionNr < allExtensions.length; extensionNr++) {
			for (extensionChildNr = 0;
			     extensionChildNr < allExtensions[extensionNr].childNodes.length;
			     extensionChildNr++){
			    switch(allExtensions[extensionNr].childNodes[extensionChildNr].nodeName){
			    case 'gpxx:DisplayColor':
				var gpxStyle = OpenLayers.Util.getXmlNodeValue
				    (allExtensions[extensionNr].childNodes[extensionChildNr]);
				layerTrack[trackNr].style = gpxColorStyle[gpxStyle.toLowerCase()];
				break}}}
		} // if (reqTrackStyle == 'gpx'
		    break;
	    case 'trkseg': // ziehe alle Trackpoints
		var allTrackpoints =
		    allTracks[trackNr].childNodes[trackChildNr].getElementsByTagName('trkpt');	
		var trackPoints = [];
		for (var pointNr = 0; pointNr < allTrackpoints.length; pointNr++) {
		    var lat = allTrackpoints[pointNr].getAttribute('lat');
		    var lon = allTrackpoints[pointNr].getAttribute('lon');
		    var newTrackPoint = new OpenLayers.Geometry.Point(lon,lat).
			transform(epsg4326, epsg900913);
		    trackPoints.push(newTrackPoint);}
		var lineString = new OpenLayers.Geometry.LineString(trackPoints);
		var trackFeature =
		    new OpenLayers.Feature.Vector(lineString, null, layerTrack[trackNr].style);
		layerTrack[trackNr].addFeatures([trackFeature]);
	    default:
		break;} // case-Schleife (name/trackseg) Ende
	} // TrackChildren-Schleife Ende
	// extend viewport to track 
	dataBounds.extend(layerTrack[trackNr].getDataExtent());
    } // Tracks-Schleife Ende
    // Ziehe Waypoints aus GPX-File
    var allWaypoints = doc.getElementsByTagName("wpt");	
    for (var waypointNr = 0; waypointNr < allWaypoints.length; waypointNr++) {
	var lat = allWaypoints[waypointNr].getAttribute('lat');
	var lon = allWaypoints[waypointNr].getAttribute('lon');
	var WaypointIcon = 'simple';
	var WaypointText = '';
	var ll = new OpenLayers.LonLat(lon,lat).transform(epsg4326, epsg900913);
	for (var waypointChildNr = 0; waypointChildNr <
		 allWaypoints[waypointNr].childNodes.length; waypointChildNr++) {
	    switch (allWaypoints[waypointNr].childNodes[waypointChildNr].nodeName) {
	    case 'name': // ziehe Namen
		var nameChild = OpenLayers.Util.getXmlNodeValue(allWaypoints[waypointNr].
								childNodes[waypointChildNr]);
		if (nameChild.length > 0) {
		    WaypointText = '<div class="WPname">'+nameChild+'</div>'}
		break;
	    case 'desc': // get description
		var descChild = OpenLayers.Util.getXmlNodeValue(allWaypoints[waypointNr].
								childNodes[waypointChildNr]);
		WaypointText = WaypointText.concat('<div class="WPdesc">',descChild,'</div>');
		break;
	    case 'sym': // get symbol
		WaypointIcon = OpenLayers.Util.getXmlNodeValue
		    (allWaypoints[waypointNr].childNodes[waypointChildNr]);
		break;
	    default:
		break;} // Caseschleife Ende
	} // Waypoint-Children-Schleife Ende
	// add waypoint to map
	addMarkerWithPopup(waypointNr,ll,WaypointIcon.toLowerCase(),WaypointText)
    } // Waypointschleife Ende
    // extend viewport to markers
    dataBounds.extend(layerWaypoints.getDataExtent());
    // set selected basemap
    map.setBaseLayer(baseMap[reqBaseMap]);
    // draw map with according viewport
    map.zoomToExtent(dataBounds);
    // show tracks
    drawTracks();
    // show waypoints
    drawWaypoints();
} // File abarbeiten Ende







//////////////////////
//
// this is intmainvoid
function showTrack(){

    // remove noscript part (this is an IE special) ###
    document.getElementById("noscript").style.display = "none";

    // set "please wait" in background of body
    document.getElementsByTagName("body")[0].style.backgroundImage =
	'url("' + uiPicuresPath + 'pleaseWait_' + UIlanguage  + '.png")';

    // if no valid basemap was defined, set warning message and exit
    var basemapCounter = 0;
    for (var layer in baseMap) {basemapCounter++}
    if (basemapCounter == 0){
	document.getElementsByTagName("body")[0].style.backgroundImage =
	    'url("' + uiPicuresPath + 'noBaseMap_' + UIlanguage + '.png")';
	return;}

    // process parameters given to the script
    for (var i = 0; i < showTrack.arguments.length; i++) {
	if (typeof(showTrack.arguments[i]) == 'string' &&
	    showTrack.arguments[i].indexOf('=') != -1) {
	    processMapParameters(showTrack.arguments[i])}}

    // setup markers path
    // (located here to have more flexibility in user configuration)
    for (var WPicon in waypointIcon) {
 	waypointIcon[WPicon].url = markerPath + waypointIcon[WPicon].url}
    
    // load standard GPX file
    var getGPXfile = OpenLayers.Request.GET({
	    url: gpxFilename,async: false});

    // if failed, load alternative GPX file
    if (getGPXfile.status == '404'){
	gpxFilename = gpxPath.concat(baseFilename,alternativeGPXfilePostfix,'.gpx');
	getGPXfile = OpenLayers.Request.GET({
		url: gpxFilename,async: false});
	reqBaseMap = alternativeGpxBaseMap}

    // if failed, load fallback GPX file
    if (getGPXfile.status == '404'){
	gpxFilename = gpxPath.concat(fallbackGPXfile);
	getGPXfile = OpenLayers.Request.GET({
		url: gpxFilename,async: false});
	reqBaseMap = globalGpxBaseMap}

    // if no valid GPX data was found, set warning message and exit
    if (getGPXfile.status == '404'){
	document.getElementsByTagName("body")[0].style.backgroundImage =
	    'url("' + uiPicuresPath + 'noGPXdataFound_' + UIlanguage + '.png")';
	return;}

    // set size of map div
    var mapDiv = document.getElementById('map');
    mapDiv.style.width = '' + getWidth() + 'px';
    mapDiv.style.height = '' + getHeight() + 'px';

    // build the map
    map = new OpenLayers.Map('map', {
	    controls: [
		       new OpenLayers.Control.Navigation({zoomWheelEnabled: false}),
		       new OpenLayers.Control.LayerSwitcher(),
		       new OpenLayers.Control.ScaleLine(),
  		       new OpenLayers.Control.ZoomPanel({displayClass:'zoomPanel'}),
		       new OpenLayers.Control.Attribution()
		       ],
	    units: 'm',
	    fallThrough: false,
 	    maxExtent: new OpenLayers.Bounds(-20037508.34,-20037508.34,20037508.34,20037508.34),
	    maxResolution: 156543.0399,
	    projection: epsg900913,
	    displayProjection: epsg4326});

    // add shading layer if one has been defined
    if (typeof(shadingLayer) != 'undefined' && showShadingLayer == true){
	shadingLayer.setName(lang[UIlanguage]['shadingLayerName']);
	map.addLayer(shadingLayer)}

    // add layers defined in configuration file
    for (var newLayer in baseMap) {
	map.addLayer(baseMap[newLayer])}

    // redefine world icon function to adjust map on track
    map.zoomToMaxExtent = function(){
	map.zoomToExtent(dataBounds);}

    // set name of waypoint layer according to selected UI language
    layerWaypoints.setName(lang[UIlanguage]['waypointLayerName']);
    
    // now process GPX data from file
    var doc = getGPXfile.responseXML;
    if (!doc || getGPXfile.fileType!="XML") {
	doc = OpenLayers.parseXMLString(getGPXfile.responseText);}
    if (typeof doc == "string") {
	doc = OpenLayers.parseXMLString(doc);}
    getDataFromFile(doc);

    // setup content for service section
    if (showHelpPageLink == true) { // if link to help file is enabled
	// take users own one, if provided
	if (lang[UIlanguage]['helpURL'].length > 0) {
	    serviceSectionHelpLinkText = '<a href="' + lang[UIlanguage]['helpURL'] +
		'" target="_blank">' + lang[UIlanguage]['help'] + '</a>'}
	// if not, use default help link
	else{serviceSectionHelpLinkText = '<a href="' + docPath + UIlanguage +
		'/' + 'userhelp.html" target="_blank">' + lang[UIlanguage]['help'] + '</a>'}}
    if (showDownloadLink == true) { // if link to gpx file enabled
	serviceSectionDownloadLinkText = '<a href="./' +
	    gpxFilename+'" type="application/gpx+xml" target="_blank">' +
	    lang[UIlanguage]['GPX file'] + '</a>'}
    if (showMapOnlyLink == true) { // if link to map only view enabled
	var parentDocument = '';
	// try to get parent URL (what could possibly cause an error)
	try{parentDocument = parent.parent.document.location.href}
	catch(e){}
	// and show link to map page if there is a parent document
	if (parentDocument != document.URL) {
	    serviceSectionMapOnlyLinkText = '<a href="' + document.URL +
		'" target="_blank">' + lang[UIlanguage]['map only'] + '</a>'}
	setupServiceSection(); // finally setup service section
    }
} // intmainvoid


// emacs stuff

// Local Variables:   //
// mode: Java         //
// coding: utf-8      //
// End:               //
