/*
 * viewer options
 */

// show link to GPX file in map: true or false
var showDownloadLink = true;
// show link to map html file
var showMapOnlyLink = true;
// show link to help page
var showHelpPageLink = true;

// default style for track
var defaultTrackStyle = 'red';

// fallback style for gpx colors
var fallbackGPXtrackStyle = 'red';

// default style for markers
var defaultMarkerStyle = 'disk';

// show gpx symbols inside markers
var showGPXsymbols = true;

// default background map
var defaultBaseMap = 'mapnik';

// default background map for alternative GPX file
var alternativeGpxBaseMap = 'mapnik';

// default background map for global GPX file
var globalGpxBaseMap = 'mapnik';

// show height layer in map
var showShadingLayer = true;

// set language for user interface
var defaultUIlanguage = 'de';

/*
 * files and dirs
 */

// postfix for alternative GPX files
var alternativeGPXfilePostfix = '-alt';

// filename of fallback GPX file
var fallbackGPXfile = 'global.gpx';

// subdirectory for GPX tracks
var gpxPath = './gpx/';

// subdirectory for documentation (help) files
var docPath = './doc/';

// subdirectory for waypoint markers
var markerPath = './pix/markers/';

// subdirectory for waypoint markers
var uiPicuresPath = './pix/ui/';


/*
 * texts parts in different languages
 */

// initialize
var lang = new Object();
lang['de'] = new Object();
lang['en'] = new Object();

// text elements
lang['de']['map only'] = 'nur Karte';
lang['en']['map only'] = 'map only';

lang['de']['GPX file'] = 'GPX-Datei';
lang['en']['GPX file'] = 'GPX file';

lang['de']['waypointLayerName'] = 'Wegpunkte';
lang['en']['waypointLayerName'] = 'waypoints';

lang['de']['shadingLayerName'] = 'Relief';
lang['en']['shadingLayerName'] = 'relief';

lang['de']['help'] = 'Hilfe';
lang['en']['help'] = 'help';

// URLs for own help pages
lang['de']['helpURL'] = '';
lang['en']['helpURL'] = '';



/*
 * define base maps
 */
var baseMap = [];

/*
 * maps need appropriate java script code loaded in the HTML file
 */

/*
 * OpenStreetMap
 * -------------
 * Insert
 * <script src="http://www.openstreetmap.org/openlayers/OpenStreetMap.js" type="text/javascript"></script>
 * to HTML file for using these basemaps
 */

try{baseMap['mapnik'] = new OpenLayers.Layer.OSM.Mapnik
	('Mapnik',{numZoomLevels: 16})} catch (e) {};

try{baseMap['cycleMap'] = new OpenLayers.Layer.OSM.CycleMap
	("Cycle Map",{numZoomLevels: 14})} catch (e) {};

try{baseMap['osmarender'] = new OpenLayers.Layer.OSM.Osmarender
	("Osmarender",{numZoomLevels: 15})} catch (e) {};


/*
 * Virtual Earth
 * -------------
 * Insert
 * <script src="http://ecn.dev.virtualearth.net/mapcontrol/mapcontrol.ashx?v=6.2&mkt=en-us"></script>
 * to HTML file for using these basemaps
 */

try{baseMap['Virtual Earth Aerial'] = new OpenLayers.Layer.VirtualEarth
	("VE Aerial", {'sphericalMercator': true,
		       'type': VEMapStyle.Aerial,
		       'numZoomLevels': 15})} catch (e) {};

try{baseMap['Virtual Earth Roads'] = new OpenLayers.Layer.VirtualEarth
	("VE Roads", {'sphericalMercator': true,
		      'type': VEMapStyle.Roads,
		      'numZoomLevels': 15})} catch (e) {};

try{baseMap['Virtual Earth Hybrid'] = new OpenLayers.Layer.VirtualEarth
	("VE Hybrid", {'sphericalMercator': true,
		       'type': VEMapStyle.Hybrid,
		       'numZoomLevels': 15})} catch (e) {};


/*
 * Yahoo 
 * -----
 * Insert
 * <script src="http://api.maps.yahoo.com/ajaxymap?v=3.0&appid=euzuro-openlayers"></script>
 * to HTML file for using these basemaps
 */

try{baseMap['Yahoo Street'] = new OpenLayers.Layer.Yahoo
	("Yahoo Street", {'sphericalMercator': true,
			  'type': YAHOO_MAP_REG})} catch (e) {};

try{baseMap['Yahoo Sat'] = new OpenLayers.Layer.Yahoo
	("Yahoo Satellite",{'sphericalMercator': true,
			    'type': YAHOO_MAP_SAT})} catch (e) {};

try{baseMap['Yahoo Hybrid'] = new OpenLayers.Layer.Yahoo
	("Yahoo Hybrid",{'sphericalMercator': true,
			 'type': YAHOO_MAP_HYB,
			 'sphericalMercator': true})} catch (e) {};


/*
 * Google
 * ------
 * Insert
 * <script src="http://maps.google.com/maps?file=api&amp;v=2&amp;key=[YourValidKeyHere]" type="text/javascript"></script>
 * to HTML file for using these basemaps
 */

try{baseMap['google satellite'] = new OpenLayers.Layer.Google
	("Google Satellite", {'sphericalMercator': true,
			      'type': G_SATELLITE_MAP,
			      'numZoomLevels': 22})} catch (e) {};

try{baseMap['google physical'] = new OpenLayers.Layer.Google
	("Google Physical",{'sphericalMercator': true,
			    'type': G_PHYSICAL_MAP})} catch (e) {};

try{baseMap['google streets'] = new OpenLayers.Layer.Google
	("Google Streets",{'sphericalMercator': true,
			   'type': G_NORMAL_MAP,
			   'numZoomLevels': 20})} catch (e) {};

try{baseMap['google hybrid'] = new OpenLayers.Layer.Google
	("Google Hybrid",{'sphericalMercator': true,
			  'type': G_HYBRID_MAP,
			  'numZoomLevels': 20})} catch (e) {};

/*
 * define a shading layer
 */
var shadingLayer =
    new OpenLayers.Layer.WMS ("Relief",
			      "http://129.206.229.158/cached/hillshade?",{
				  layers: 'europe_wms:hs_srtm_europa',
				  srs: 'EPSG:900913',
				  format: 'image/JPEG'});
shadingLayer.isBaseLayer = false;
shadingLayer.setOpacity(0.19);


/*
 * track styles
 */

var trackStyle = [];
function buildTrackStyle() {
    trackStyle[buildTrackStyle.arguments[0]] = [];
    for (var i = 1; i < buildTrackStyle.arguments.length; i++) {
	trackStyle[buildTrackStyle.arguments[0]].push
	    ({'strokeColor':buildTrackStyle.arguments[i],
		    'strokeOpacity':0.88,
		    'strokeWidth':3,
		    'strokeDashstyle':'longdash'
		    })}}

buildTrackStyle('grey','#aaaaaa','#000000','#ffffff','#555555');
buildTrackStyle('red','#ff0000','#a60000','#ff5757','#d20000');
buildTrackStyle('green','#00ff00','#00c000','#91ff91','#00e000');
buildTrackStyle('blue','#0000ff','#00009a','#5757ff','#0000cc');
buildTrackStyle('cyan','#00ffff','#00cacc','#bdfeff','#00e3e6');
buildTrackStyle('pink','#ff00ff','#b200b0','#ff7ffd','#d800d5');
buildTrackStyle('yellow','#ffff00','#bec000','#feff9d','#e3e600');
buildTrackStyle('orange','#ffbb00','#ba8800','#ffd257','#e0a300');

// GPX colors
gpxColorStyle = [];
gpxColorStyle['transparent'] = {strokeColor: '#000000',strokeOpacity: 0,strokeWidth: 0};
gpxColorStyle['white'] = trackStyle['grey'][2];
gpxColorStyle['lightgray'] = trackStyle['grey'][0];
gpxColorStyle['darkgray'] = trackStyle['grey'][3];
gpxColorStyle['black'] = trackStyle['grey'][1];
gpxColorStyle['red'] = trackStyle['red'][0];
gpxColorStyle['darkred'] = trackStyle['red'][1];
gpxColorStyle['green'] = trackStyle['green'][0];
gpxColorStyle['darkgreen'] = trackStyle['green'][1];
gpxColorStyle['yellow'] = trackStyle['yellow'][0];
gpxColorStyle['darkyellow'] = trackStyle['yellow'][1];
gpxColorStyle['blue'] = trackStyle['blue'][0];
gpxColorStyle['darkblue'] = trackStyle['blue'][1];
gpxColorStyle['magenta'] = trackStyle['pink'][0];
gpxColorStyle['darkmagenta'] = trackStyle['pink'][1];
gpxColorStyle['cyan'] = trackStyle['cyan'][0];
gpxColorStyle['darkcyan'] = trackStyle['cyan'][1];


/*
 * waypoint stuff
 */

// the layer
var layerWaypoints = new OpenLayers.Layer.Markers('Waypoints');

/*
 * icons
 */

// setting sizes
var size = new OpenLayers.Size(15,15); // default size of icons
var offset = new OpenLayers.Pixel(-8, -8); // default offset of icons

// defining the images
var waypointIcon = []; // Array für Icons
waypointIcon['1'] = new OpenLayers.Icon('01.png',size,offset);
waypointIcon['2'] = new OpenLayers.Icon('02.png',size,offset);
waypointIcon['3'] = new OpenLayers.Icon('03.png',size,offset);
waypointIcon['4'] = new OpenLayers.Icon('04.png',size,offset);
waypointIcon['5'] = new OpenLayers.Icon('05.png',size,offset);
waypointIcon['6'] = new OpenLayers.Icon('06.png',size,offset);
waypointIcon['7'] = new OpenLayers.Icon('07.png',size,offset);
waypointIcon['8'] = new OpenLayers.Icon('08.png',size,offset);
waypointIcon['9'] = new OpenLayers.Icon('09.png',size,offset);
waypointIcon['10'] = new OpenLayers.Icon('10.png',size,offset);
waypointIcon['11'] = new OpenLayers.Icon('11.png',size,offset);
waypointIcon['12'] = new OpenLayers.Icon('12.png',size,offset);
waypointIcon['ballpark'] = new OpenLayers.Icon('baseball.png',size,offset);
waypointIcon['bar'] = new OpenLayers.Icon('bar.png',size,offset);
waypointIcon['bike trail'] = new OpenLayers.Icon('bike.png',size,offset);
waypointIcon['break'] = new OpenLayers.Icon('break.png',size,offset);
waypointIcon['bridge'] = new OpenLayers.Icon('bridge.png',size,offset);
waypointIcon['car'] = new OpenLayers.Icon('car.png',size,offset);
waypointIcon['cemetery'] = new OpenLayers.Icon('cemetery.png',size,offset);
waypointIcon['church'] = new OpenLayers.Icon('church.png',size,offset);
waypointIcon['drinking water'] = new OpenLayers.Icon('drinkingwater.png',size,offset);
waypointIcon['fast food'] = new OpenLayers.Icon('burger.png',size,offset);
waypointIcon['flag, blue'] = new OpenLayers.Icon('flag_blue.png',size,offset);
waypointIcon['flag, green'] = new OpenLayers.Icon('flag_green.png',size,offset);
waypointIcon['flag, red'] = new OpenLayers.Icon('flag_red.png',size,offset);
waypointIcon['flag, yellow'] = new OpenLayers.Icon('flag_yellow.png',size,offset);
waypointIcon['forest'] = new OpenLayers.Icon('forest.png',size,offset);
waypointIcon['geocache'] = new OpenLayers.Icon('geocache.png',size,offset);
waypointIcon['ground transportation'] = new OpenLayers.Icon('railway.png',size,offset);
waypointIcon['museum'] = new OpenLayers.Icon('museum.png',size,offset);
waypointIcon['park'] = new OpenLayers.Icon('park.png',size,offset);
waypointIcon['parking area'] = new OpenLayers.Icon('parkingarea.png',size,offset);
waypointIcon['picnic area'] = new OpenLayers.Icon('picnicarea.png',size,offset);
waypointIcon['railway'] = new OpenLayers.Icon('railway.png',size,offset);
waypointIcon['railstation'] = new OpenLayers.Icon('railstation.png',size,offset);
waypointIcon['residence'] = new OpenLayers.Icon('residence.png',size,offset);
waypointIcon['restaurant'] = new OpenLayers.Icon('restaurant.png',size,offset);
waypointIcon['scenic area'] = new OpenLayers.Icon('camera.png',size,offset);
waypointIcon['shopping center'] = new OpenLayers.Icon('shoppingcenter.png',size,offset);
waypointIcon['simple'] = new OpenLayers.Icon('empty.png',size,offset);
waypointIcon['summit'] = new OpenLayers.Icon('summit.png',size,offset);
waypointIcon['swimming area'] = new OpenLayers.Icon('swimming.png',size,offset);
waypointIcon['tall tower'] = new OpenLayers.Icon('talltower.png',size,offset);
waypointIcon['trail head'] = new OpenLayers.Icon('walker.png',size,offset);
waypointIcon['water source'] = new OpenLayers.Icon('watersource.png',size,offset);
waypointIcon['waypoint'] = new OpenLayers.Icon('pennon.png',size,offset);
// waypointIcon[''] = new OpenLayers.Icon('empty.png',size,offset);
